<?php
/**
 * Plugin Name: Really Simple SSL pro
 * Plugin URI: https://really-simple-ssl.com/pro
 * Description: Optimize your SSL security with the mixed content scan, secure cookies and advanced security headers.
 * Version: 5.5.5
 * Text Domain: really-simple-ssl-pro
 * Domain Path: /languages
 * Author: Really Simple Plugins
 * Author URI: https://www.really-simple-plugins.com
 */

/*  Copyright 2022  Really Simple Plugins B.V.  (email : support@really-simple-ssl.com)
    License: see license.txt
*/

update_site_option( 'rsssl_pro_license_key', 'activated' );
update_site_option( 'rsssl_pro_license_status', 'valid' );
update_site_option( 'rsssl_pro_license_activation_limit', '999' );
update_site_option( 'rsssl_pro_license_activations_left', '999' );
update_site_option( 'rsssl_pro_license_expires', 'lifetime' );
define( 'rsssl_pro_ms_version', true );

defined('ABSPATH') or die("you do not have access to this page!");

if (!function_exists('rsssl_pro_activation_check')) {
	/**
	 * Checks if the plugin can safely be activated, at least php 5.6 and wp 4.8
	 */
	function rsssl_pro_activation_check()
	{
		if (version_compare(PHP_VERSION, '7.2', '<')) {
			deactivate_plugins(plugin_basename(__FILE__));
			wp_die(__('Really Simple SSL pro cannot be activated. The plugin requires PHP 5.6 or higher', 'really-simple-ssl-pro'));
		}

		global $wp_version;
		if (version_compare($wp_version, '5.0', '<')) {
			deactivate_plugins(plugin_basename(__FILE__));
			wp_die(__('Really Simple SSL pro cannot be activated. The plugin requires WordPress 4.9 or higher', 'really-simple-ssl-pro'));
		}
	}
	register_activation_hook( __FILE__, 'rsssl_pro_activation_check' );
}
if (!class_exists('REALLY_SIMPLE_SSL_PRO')) {
class REALLY_SIMPLE_SSL_PRO {

    private static $instance;
    public $rsssl_server;
    public $really_simple_ssl;
    public $rsssl_help;
    public $rsssl_support;
    public $rsssl_licensing;
    public $rsssl_csp_backend;
    public $rsssl_premium_options;
    public $rsssl_headers;
    public $rsssl_scan;
    public $rsssl_importer;

    private function __construct() {
        if (isset($_GET['rsssl_apitoken']) && $_GET['rsssl_apitoken'] == rsssl_get_networkwide_option('rsssl_csp_report_token') ) {
            if ( !defined('RSSSL_DOING_CSP') ) define( 'RSSSL_DOING_CSP' , true );
        }
    }

    public static function instance() {
        if ( ! isset( self::$instance ) && ! ( self::$instance instanceof REALLY_SIMPLE_SSL_PRO ) ) {
            self::$instance = new REALLY_SIMPLE_SSL_PRO;
            if (self::$instance->is_compatible()) {
                self::$instance->setup_constants();
                self::$instance->includes();

                if ( is_admin() || defined('RSSSL_DOING_SYSTEM_STATUS') || defined('RSSSL_DOING_CSP') ) {
                    //load before premium options, to ensure that header check has run first.
	                self::$instance->rsssl_headers         = new rsssl_headers();
	                self::$instance->rsssl_premium_options = new rsssl_premium_options();
	                self::$instance->rsssl_scan            = new rsssl_scan();
	                self::$instance->rsssl_importer        = new rsssl_importer();
                    self::$instance->rsssl_support         = new rsssl_support();
                    self::$instance->rsssl_csp_backend     = new rsssl_csp_backend();
                }
	            self::$instance->rsssl_licensing       = new rsssl_licensing();

	            self::$instance->hooks();
	            self::$instance->load_translation();
            } else {
	            self::$instance->setup_constants();
	            add_action('admin_notices', array('REALLY_SIMPLE_SSL_PRO', 'admin_notices'));
                add_action('admin_enqueue_scripts' , array( 'REALLY_SIMPLE_SSL_PRO', 'enqueue_installer_script_styles' ) );
	            add_action( 'wp_ajax_rsssl_install_plugin', array( 'REALLY_SIMPLE_SSL_PRO', 'maybe_install_suggested_plugins' ) );
            }

        }

        return self::$instance;
    }

    /**
       Checks if one of the necessary plugins is active, and of the required version.
    */

    public function is_compatible(){
        require_once(ABSPATH.'wp-admin/includes/plugin.php');
        $core_plugin = 'really-simple-ssl/rlrsssl-really-simple-ssl.php';
	    $core_plugin_data = $per_page_plugin_data = false;

        if ( is_plugin_active($core_plugin)) $core_plugin_data = get_plugin_data( WP_PLUGIN_DIR .'/'. $core_plugin, false, false );


        //this older version is not compatible with newer free version
	    if ( is_plugin_active($core_plugin) && $core_plugin_data && version_compare($core_plugin_data['Version'] ,'6.0.0','>=') ) {
		    return false;
	    }

        if ( is_plugin_active($core_plugin) && $core_plugin_data && version_compare($core_plugin_data['Version'] ,'5.2.0','>=') ) {
            return true;
        }

        //drop per page plugin integration
        $per_page_plugin = 'really-simple-ssl-on-specific-pages/really-simple-ssl-on-specific-pages.php';
        if (is_plugin_active($per_page_plugin))  {
            return false;
        }

        //nothing yet? then...sorry, but no, not compatible.
        return false;
    }

    private function setup_constants() {
        define('rsssl_pro_url', plugin_dir_url(__FILE__ ));
        define('rsssl_pro_path', plugin_dir_path(__FILE__ ));
        define('rsssl_pro_plugin', plugin_basename( __FILE__ ) );
	    define('rsssl_pro_template_path', trailingslashit(plugin_dir_path(__FILE__)).'grid/templates/');

	    $debug = ( defined( 'RSSSL_DEBUG' ) && RSSSL_DEBUG ) ? time() : '';
	    define('rsssl_pro_version', '5.5.5' . $debug );
        define('rsssl_pro_plugin_file', __FILE__);
        if (!defined('REALLY_SIMPLE_SSL_URL')) define( 'REALLY_SIMPLE_SSL_URL', 'https://really-simple-ssl.com');
        define( 'RSSSL_ITEM_ID', 860 );
        define( 'RSSSL_ITEM_NAME', 'Really Simple SSL Pro' );
        define( 'RSSSL_ITEM_VERSION', rsssl_pro_version );
    }

    private function includes() {

        if ( is_admin() || defined('RSSSL_DOING_SYSTEM_STATUS') || defined('RSSSL_DOING_CSP') ) {
            require_once(rsssl_pro_path . '/csp-violation-endpoint.php');
	        require_once(rsssl_pro_path . '/class-headers.php' );
	        require_once(rsssl_pro_path . '/class-premium-options.php');
	        require_once(rsssl_pro_path . '/class-scan.php');
            require_once(rsssl_pro_path . '/class-cert-expiration.php');
	        require_once(rsssl_pro_path . '/class-importer.php' );
	        require_once(rsssl_pro_path . '/class-support.php');
	        require_once(rsssl_pro_path . '/modal/class-modal.php');
        }
	    require_once(rsssl_pro_path . '/class-licensing.php');


    }

	/**
	 * Load plugin translations.
	 *
	 * @since 1.0.0
	 *
	 * @return void
	 */
	private function load_translation() {
		load_plugin_textdomain('really-simple-ssl-pro', FALSE, dirname(plugin_basename(__FILE__) ) . '/languages/');
	}

    private function hooks() {

    }

	/**
	 * Enqueue plugin installer script
	 */
    public static function enqueue_installer_script_styles() {
	    $minified = ( defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ) ? '' : '.min';

	    wp_register_style( 'rsssl-admin', rsssl_pro_url . "css/admin$minified.css", false, rsssl_pro_version );
	    wp_enqueue_style( 'rsssl-admin' );

	    wp_enqueue_script( 'rsssl-admin', rsssl_pro_url . "js/admin$minified.js", array( 'jquery' ), rsssl_pro_version, true );

	    wp_localize_script(
		    'rsssl-admin',
		    'rsssl_admin',
		    array(
			    'admin_url'        => admin_url( 'admin-ajax.php' ),
                'plugin_page_url'  => add_query_arg( array(
	                "page" => "rlrsssl_really_simple_ssl",
	                "tab" => 'configuration',
                ), admin_url( "options-general.php" ) ),
		    )
	    );
    }


    /**
     * Handles the displaying of any notices in the admin area
     *
     * @since 1.0.28
     * @access public
     * @return void
     */

    public static function admin_notices() {
        //prevent showing the review on edit screen, as gutenberg removes the class which makes it editable.
        $screen = get_current_screen();
	    if ( $screen->base === 'post' ) return;

	    $per_page_plugin_data = false;
	    $core_plugin_data = false;

        require_once(ABSPATH.'wp-admin/includes/plugin.php');
        $core_plugin = 'really-simple-ssl/rlrsssl-really-simple-ssl.php';
        if (is_plugin_active($core_plugin)) $core_plugin_data = get_plugin_data( trailingslashit(WP_PLUGIN_DIR) . $core_plugin, false, false );
        $per_page_plugin = 'really-simple-ssl-on-specific-pages/really-simple-ssl-on-specific-pages.php';
        if ( is_plugin_active($per_page_plugin)) $per_page_plugin_data = get_plugin_data( trailingslashit(WP_PLUGIN_DIR) . $per_page_plugin, false, false );
        if ( defined('rsssl_pp_version') ){ ?>
            <div id="rsssl-message" class="notice error really-simple-plugins">
                <div class="rsssl-notice">
                    <div class="rsssl-notice-content">
                        <p><?php echo __("You are using Really Simple SSL per page, which is no longer supported in combination with Really Simple SSL pro.","really-simple-ssl-pro");?></p>
                        <p><?php echo __("We recommend to change per page to Really Simple SSL instead, and move your entire site to SSL.","really-simple-ssl-pro");?></p>
                    </div>
                </div>
            </div>
                <?php
        } else if ( !is_plugin_active($core_plugin) && !is_plugin_active($per_page_plugin)) {
            ?>
            <div id="rsssl-message" class="notice error really-simple-plugins">
                <div class="rsssl-notice">
                    <div class="rsssl-notice-content">
                        <?php if ( !defined( 'rsssl_plugin' ) ) {
                            ?>
                            <p> <?php echo __("Really Simple SSL pro is an add-on for Really Simple SSL, and cannot do it on its own :-(","really-simple-ssl-pro"); ?> </p>
                            <p> <?php echo __("Please install and activate Really Simple SSL to enable the add-on.","really-simple-ssl-pro"); ?> </p> <?php
                        } else { ?>
                            <p><?php echo sprintf(__("Please %supgrade%s to the latest version to be able use the full functionality of the plugin.","really-simple-ssl-pro"),'<a href="https://really-simple-ssl.com/pro" target="_blank">','</a>');?></p>
                        <?php }?>
                    </div>
                    <div class="rsssl-notice-footer">
                        <?php
                        require_once( rsssl_pro_path . 'class-installer.php' );
                        // Install and activate Really Simple SSL
                        new rsssl_installer( 'really-simple-ssl' );
                        ?>
                        <div><button type="button" class="button-primary rsssl-install-plugin"><?php echo __("Install and activate Really Simple SSL","really-simple-ssl-pro") ?></button>
                        </div>
                    </div>
                </div>
            </div>
            <?php
        } else if ( $core_plugin && isset($core_plugin_data['Version']) && version_compare($core_plugin_data['Version'], '4.0.9', '<=')) {
            ?>
            <div id="rsssl-message" class="notice error really-simple-plugins">
                <div class="rsssl-notice">
                    <div class="rsssl-notice-content">
                        <p><?php echo __("Really Simple SSL needs to be updated to the latest version to be compatible.","really-simple-ssl-pro");?></p>
                        <p><?php echo sprintf(__("Please %supgrade%s to the latest version to be able use the full functionality of the plugin.","really-simple-ssl-pro"),'<a href="https://really-simple-ssl.com/pro" target="_blank">','</a>');?></p>
                    </div>
                </div>
            </div>
            <?php
        }
    }

	/**
     * Install suggested plugins
	 * @return void
	 */
	public static function maybe_install_suggested_plugins(){
		$error = true;
		if ( current_user_can('install_plugins')) {
			$error = false;
			$step = isset($_GET['step']) ? sanitize_title($_GET['step']) : 'download';
			require_once( rsssl_pro_path . 'class-installer.php' );
			$installer = new rsssl_installer( 'really-simple-ssl' );
			$installer->install($step);
		}

		$response = json_encode( [ 'success' => $error ] );
		header( "Content-Type: application/json" );
		echo $response;
		exit;
	}
}
}

if (!class_exists('REALLY_SIMPLE_SSL_PRO_MULTISITE')) {
	if (!function_exists('RSSSL_PRO') ){
        function RSSSL_PRO() {
	        return REALLY_SIMPLE_SSL_PRO::instance();
		}
    }
	add_action( 'plugins_loaded', 'RSSSL_PRO', 9 );
}

require_once( plugin_dir_path(__FILE__ ) . '/front-end.php' );
require_once( plugin_dir_path(__FILE__ ) . '/csp-endpoint-public.php' );

/**
 * Set some defaults
 */
if (!function_exists('rsssl_pro_set_defaults_on_activation')) {
	function rsssl_pro_set_defaults_on_activation()
	{
	    set_transient('rsssl_pro_redirect_to_settings_page', true, DAY_IN_SECONDS );
		if ( REALLY_SIMPLE_SSL_PRO::instance()->is_compatible() ) {
            RSSSL_PRO()->rsssl_premium_options->set_defaults();
		}
	}
}
register_activation_hook(__FILE__ ,'rsssl_pro_set_defaults_on_activation');

if ( !function_exists('rsssl_pro_deactivate') ) {
	function rsssl_pro_deactivate()
	{
		wp_clear_scheduled_hook('rsssl_pro_daily_hook');
        rsssl_pro_remove_advanced_headers();
		if (REALLY_SIMPLE_SSL_PRO::instance()->is_compatible() ) RSSSL_PRO()->rsssl_premium_options->deactivate();
	}
	register_deactivation_hook( __FILE__, 'rsssl_pro_deactivate');
}

if ( ! function_exists('rsssl_pro_remove_advanced_headers') ) {
    function rsssl_pro_remove_advanced_headers() {
	    $file = ABSPATH . 'wp-content/advanced-headers.php';
        if ( !defined('rsssl_version') ) {
            return;
        }

        //below class doesn't exist in 6.0.
        if (version_compare(rsssl_version, '6.0','<')) {
            return;
        }

	    $wpconfig_path = RSSSL()->really_simple_ssl->find_wp_config_path();
	    if ( is_writable( $wpconfig_path ) ) {
		    $wpconfig = file_get_contents( $wpconfig_path );

		    $rule = "if ( file_exists('" . $file . "') ) { " . "\n";
		    $rule .= "\t" . "require_once '$file';" . "\n" . "}";

		    if ( strpos( $wpconfig, $rule ) !== false ) {
			    $updated_wpconfig = str_replace( $rule, '', $wpconfig );
			    file_put_contents( $wpconfig_path, $updated_wpconfig );
		    }
	    }

	    if ( file_exists( $file ) ) {
		    unlink( $file );
	    }
    }
}